[jboss-cvs] JBossAS SVN: r83897 - trunk/server/src/main/org/jboss/web/deployers.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Thu Feb 5 08:37:48 EST 2009


Author: alesj
Date: 2009-02-05 08:37:48 -0500 (Thu, 05 Feb 2009)
New Revision: 83897

Modified:
   trunk/server/src/main/org/jboss/web/deployers/AbstractWarDeployer.java
Log:
Use legacy unjar.

Modified: trunk/server/src/main/org/jboss/web/deployers/AbstractWarDeployer.java
===================================================================
--- trunk/server/src/main/org/jboss/web/deployers/AbstractWarDeployer.java	2009-02-05 13:21:18 UTC (rev 83896)
+++ trunk/server/src/main/org/jboss/web/deployers/AbstractWarDeployer.java	2009-02-05 13:37:48 UTC (rev 83897)
@@ -349,12 +349,12 @@
 
             VFSDeploymentUnit vfsUnit = (VFSDeploymentUnit)unit;
             VirtualFile root = vfsUnit.getRoot();
-            VirtualFile exploded = VFSUtils.explode(root);
-            // file was not exploded yet
-            if (root != exploded)
+            VirtualFile unjared = VFSUtils.unjar(root);
+            // file was not unjared yet
+            if (root != unjared)
             {
-               // get the real exploded url
-               expWarUrl = VFSUtils.getRealURL(exploded);
+               // get the real unjared url
+               expWarUrl = VFSUtils.getRealURL(unjared);
 
                // Map
                String warPathName = root.getPathName();




More information about the jboss-cvs-commits mailing list